@@ -25,13 +25,12 @@ DEALINGS IN THE SOFTWARE.
 
 from __future__ import annotations
 
-import asyncio
-import time
 from typing import TYPE_CHECKING, Callable, Dict, Iterable, List, Optional, Union
 
-from .abc import Messageable
+from .abc import Messageable, _purge_messages_helper
 from .enums import ChannelType, try_enum
 from .errors import ClientException
+from .flags import ChannelFlags
 from .mixins import Hashable
 from .utils import MISSING, _get_as_snowflake, parse_time
 
@@ -42,7 +41,7 @@ __all__ = (
 
 if TYPE_CHECKING:
     from .abc import Snowflake, SnowflakeTime
-    from .channel import CategoryChannel, TextChannel
+    from .channel import CategoryChannel, ForumChannel, TextChannel
     from .guild import Guild
     from .member import Member
     from .message import Message, PartialMessage
@@ -87,6 +86,10 @@ class Thread(Messageable, Hashable):
         The guild the thread belongs to.
     id: :class:`int`
         The thread ID.
+
+        .. note::
+            This ID is the same as the thread starting message ID.
+
     parent_id: :class:`int`
         The parent :class:`TextChannel` ID this thread belongs to.
     owner_id: :class:`int`
@@ -121,6 +124,10 @@ class Thread(Messageable, Hashable):
     created_at: Optional[:class:`datetime.datetime`]
         An aware timestamp of when the thread was created.
         Only available for threads created after 2022-01-09.
+    flags: :class:`ChannelFlags`
+        Extra features of the thread.
+
+        .. versionadded:: 2.0
     """
 
     __slots__ = (
@@ -143,6 +150,7 @@ class Thread(Messageable, Hashable):
         "auto_archive_duration",
         "archive_timestamp",
         "created_at",
+        "flags",
     )
 
     def __init__(self, *, guild: Guild, state: ConnectionState, data: ThreadPayload):
@@ -164,15 +172,27 @@ class Thread(Messageable, Hashable):
         return self.name
 
     def _from_data(self, data: ThreadPayload):
+        # This data will always exist
         self.id = int(data["id"])
         self.parent_id = int(data["parent_id"])
-        self.owner_id = int(data["owner_id"])
         self.name = data["name"]
         self._type = try_enum(ChannelType, data["type"])
+
+        # This data may be missing depending on how this object is being created
+        self.owner_id = int(data.get("owner_id")) if data.get("owner_id", None) is not None else None
         self.last_message_id = _get_as_snowflake(data, "last_message_id")
         self.slowmode_delay = data.get("rate_limit_per_user", 0)
-        self.message_count = data["message_count"]
-        self.member_count = data["member_count"]
+        self.message_count = data.get("message_count", None)
+        self.member_count = data.get("member_count", None)
+        self.flags: ChannelFlags = ChannelFlags._from_value(data.get("flags", 0))
+
+        # Here, we try to fill in potentially missing data
+        if thread := self.guild.get_thread(self.id) and data.pop("_invoke_flag", False):
+            self.owner_id = thread.owner_id if self.owner_id is None else self.owner_id
+            self.last_message_id = thread.last_message_id if self.last_message_id is None else self.last_message_id
+            self.message_count = thread.message_count if self.message_count is None else self.message_count
+            self.member_count = thread.member_count if self.member_count is None else self.member_count
+
         self._unroll_metadata(data["thread_metadata"])
 
         try:
@@ -196,6 +216,7 @@ class Thread(Messageable, Hashable):
         except KeyError:
             pass
 
+        self.flags: ChannelFlags = ChannelFlags._from_value(data.get("flags", 0))
         self.slowmode_delay = data.get("rate_limit_per_user", 0)
 
         try:
@@ -209,7 +230,7 @@ class Thread(Messageable, Hashable):
         return self._type
 
     @property
-    def parent(self) -> Optional[TextChannel]:
+    def parent(self) -> Optional[Union[TextChannel, ForumChannel]]:
         """Optional[:class:`TextChannel`]: The parent channel this thread belongs to."""
         return self.guild.get_channel(self.parent_id)  # type: ignore
 
@@ -223,6 +244,14 @@ class Thread(Messageable, Hashable):
         """:class:`str`: The string that allows you to mention the thread."""
         return f"<#{self.id}>"
 
+    @property
+    def jump_url(self) -> str:
+        """:class:`str`: Returns a URL that allows the client to jump to the thread.
+
+        .. versionadded:: 2.0
+        """
+        return f"https://discord.com/channels/{self.guild.id}/{self.id}"
+
     @property
     def members(self) -> List[ThreadMember]:
         """List[:class:`ThreadMember`]: A list of thread members in this thread.
@@ -235,7 +264,7 @@ class Thread(Messageable, Hashable):
 
     @property
     def last_message(self) -> Optional[Message]:
-        """Fetches the last message from this channel in cache.
+        """Returns the last message from this thread in cache.
 
         The message might not be valid or point to an existing message.
 
@@ -248,7 +277,7 @@ class Thread(Messageable, Hashable):
             attribute.
 
         Returns
-        ---------
+        --------
         Optional[:class:`Message`]
             The last message in this channel or ``None`` if not found.
         """
@@ -264,7 +293,7 @@ class Thread(Messageable, Hashable):
             The parent channel was not cached and returned ``None``.
 
         Returns
-        -------
+        --------
         Optional[:class:`CategoryChannel`]
             The parent channel's category.
         """
@@ -284,7 +313,7 @@ class Thread(Messageable, Hashable):
             The parent channel was not cached and returned ``None``.
 
         Returns
-        -------
+        --------
         Optional[:class:`int`]
             The parent channel's category ID.
         """
@@ -294,6 +323,22 @@ class Thread(Messageable, Hashable):
             raise ClientException("Parent channel not found")
         return parent.category_id
 
+    @property
+    def starting_message(self) -> Optional[Message]:
+        """Returns the message that started this thread.
+
+        The message might not be valid or point to an existing message.
+
+        .. note::
+            The ID for this message is the same as the thread ID.
+
+        Returns
+        --------
+        Optional[:class:`Message`]
+            The message that started this thread or ``None`` if not found in the cache.
+        """
+        return self._state._get_message(self.id)
+
     def is_private(self) -> bool:
         """:class:`bool`: Whether the thread is a private thread.
 
@@ -351,7 +396,7 @@ class Thread(Messageable, Hashable):
             raise ClientException("Parent channel not found")
         return parent.permissions_for(obj)
 
-    async def delete_messages(self, messages: Iterable[Snowflake]) -> None:
+    async def delete_messages(self, messages: Iterable[Snowflake], *, reason: Optional[str] = None) -> None:
         """|coro|
 
         Deletes a list of messages. This is similar to :meth:`Message.delete`
@@ -373,6 +418,8 @@ class Thread(Messageable, Hashable):
         -----------
         messages: Iterable[:class:`abc.Snowflake`]
             An iterable of messages denoting which ones to bulk delete.
+        reason: Optional[:class:`str`]
+            The reason for deleting the messages. Shows up on the audit log.
 
         Raises
         ------
@@ -394,14 +441,14 @@ class Thread(Messageable, Hashable):
 
         if len(messages) == 1:
             message_id = messages[0].id
-            await self._state.http.delete_message(self.id, message_id)
+            await self._state.http.delete_message(self.id, message_id, reason=reason)
             return
 
         if len(messages) > 100:
             raise ClientException("Can only bulk delete messages up to 100 messages")
 
         message_ids: SnowflakeList = [m.id for m in messages]
-        await self._state.http.delete_messages(self.id, message_ids)
+        await self._state.http.delete_messages(self.id, message_ids, reason=reason)
 
     async def purge(
         self,
@@ -413,6 +460,7 @@ class Thread(Messageable, Hashable):
         around: Optional[SnowflakeTime] = None,
         oldest_first: Optional[bool] = False,
         bulk: bool = True,
+        reason: Optional[str] = None,
     ) -> List[Message]:
         """|coro|
 
@@ -456,6 +504,8 @@ class Thread(Messageable, Hashable):
             If ``True``, use bulk delete. Setting this to ``False`` is useful for mass-deleting
             a bot's own messages without :attr:`Permissions.manage_messages`. When ``True``, will
             fall back to single delete if messages are older than two weeks.
+        reason: Optional[:class:`str`]
+            The reason for deleting the messages. Shows up on the audit log.
 
         Raises
         -------
@@ -469,62 +519,17 @@ class Thread(Messageable, Hashable):
         List[:class:`.Message`]
             The list of messages that were deleted.
         """
-
-        if check is MISSING:
-            check = lambda m: True
-
-        iterator = self.history(
+        return await _purge_messages_helper(
+            self,
             limit=limit,
+            check=check,
             before=before,
             after=after,
-            oldest_first=oldest_first,
             around=around,
+            oldest_first=oldest_first,
+            bulk=bulk,
+            reason=reason,
         )
-        ret: List[Message] = []
-        count = 0
-
-        minimum_time = int((time.time() - 14 * 24 * 60 * 60) * 1000.0 - 1420070400000) << 22
-
-        async def _single_delete_strategy(messages: Iterable[Message]):
-            for m in messages:
-                await m.delete()
-
-        strategy = self.delete_messages if bulk else _single_delete_strategy
-
-        async for message in iterator:
-            if count == 100:
-                to_delete = ret[-100:]
-                await strategy(to_delete)
-                count = 0
-                await asyncio.sleep(1)
-
-            if not check(message):
-                continue
-
-            if message.id < minimum_time:
-                # older than 14 days old
-                if count == 1:
-                    await ret[-1].delete()
-                elif count >= 2:
-                    to_delete = ret[-count:]
-                    await strategy(to_delete)
-
-                count = 0
-                strategy = _single_delete_strategy
-
-            count += 1
-            ret.append(message)
-
-        # SOme messages remaining to poll
-        if count >= 2:
-            # more than 2 messages -> bulk delete
-            to_delete = ret[-count:]
-            await strategy(to_delete)
-        elif count == 1:
-            # delete a single message
-            await ret[-1].delete()
-
-        return ret
 
     async def edit(
         self,
@@ -535,6 +540,7 @@ class Thread(Messageable, Hashable):
         invitable: bool = MISSING,
         slowmode_delay: int = MISSING,
         auto_archive_duration: ThreadArchiveDuration = MISSING,
+        pinned: bool = MISSING,
         reason: Optional[str] = None,
     ) -> Thread:
         """|coro|
@@ -567,6 +573,8 @@ class Thread(Messageable, Hashable):
             A value of ``0`` disables slowmode. The maximum value possible is ``21600``.
         reason: Optional[:class:`str`]
             The reason for editing this thread. Shows up on the audit log.
+        pinned: :class:`bool`
+            Whether to pin the thread or not. This only works if the thread is part of a forum.
 
         Raises
         -------
@@ -593,6 +601,11 @@ class Thread(Messageable, Hashable):
             payload["invitable"] = invitable
         if slowmode_delay is not MISSING:
             payload["rate_limit_per_user"] = slowmode_delay
+        if pinned is not MISSING:
+            # copy the ChannelFlags object to avoid mutating the original
+            flags = ChannelFlags._from_value(self.flags.value)
+            flags.pinned = pinned
+            payload["flags"] = flags.value
 
         data = await self._state.http.edit_channel(self.id, **payload, reason=reason)
         # The data payload will always be a Thread payload
@@ -722,7 +735,13 @@ class Thread(Messageable, Hashable):
         """
 
         members = await self._state.http.get_thread_members(self.id)
-        return [ThreadMember(parent=self, data=data) for data in members]
+
+        thread_members = [ThreadMember(parent=self, data=data) for data in members]
+
+        for member in thread_members:
+            self._add_member(member)
+
+        return thread_members
 
     async def delete(self):
         """|coro|
