@@ -25,7 +25,7 @@ DEALINGS IN THE SOFTWARE.
 
 # If you're wondering why this is essentially copy pasted from the async_.py
 # file, then it's due to needing two separate types to make the typing shenanigans
-# a bit easier to write. It's an unfortunate design. Originally, these types were
+# a bit easier to write. It's an unfortunate design. originallyy, these types were
 # merged and an adapter was used to differentiate between the async and sync versions.
 # However, this proved to be difficult to provide typings for, so here we are.
 
@@ -308,11 +308,16 @@ class WebhookAdapter:
         multipart: Optional[List[Dict[str, Any]]] = None,
         files: Optional[List[File]] = None,
         thread_id: Optional[int] = None,
+        thread_name: Optional[str] = None,
         wait: bool = False,
     ):
         params = {"wait": int(wait)}
         if thread_id:
             params["thread_id"] = thread_id
+
+        if thread_name:
+            payload["thread_name"] = thread_name
+
         route = Route(
             "POST",
             "/webhooks/{webhook_id}/{webhook_token}",
@@ -705,7 +710,7 @@ class SyncWebhook(BaseWebhook):
             A partial webhook is just a webhook object with an ID and a token.
         """
         m = re.search(
-            r"discord(?:app)?.com/api/webhooks/(?P<id>[0-9]{17,20})/(?P<token>[A-Za-z0-9\.\-\_]{60,68})",
+            r"discord(?:app)?.com/api/webhooks/(?P<id>\d{17,20})/(?P<token>[\w\.\-_]{60,68})",
             url,
         )
         if m is None:
@@ -909,6 +914,7 @@ class SyncWebhook(BaseWebhook):
         embeds: List[Embed] = MISSING,
         allowed_mentions: AllowedMentions = MISSING,
         thread: Snowflake = MISSING,
+        thread_name: Optional[str] = None,
         wait: Literal[True],
     ) -> SyncWebhookMessage:
         ...
@@ -927,6 +933,7 @@ class SyncWebhook(BaseWebhook):
         embeds: List[Embed] = MISSING,
         allowed_mentions: AllowedMentions = MISSING,
         thread: Snowflake = MISSING,
+        thread_name: Optional[str] = None,
         wait: Literal[False] = ...,
     ) -> None:
         ...
@@ -944,6 +951,7 @@ class SyncWebhook(BaseWebhook):
         embeds: List[Embed] = MISSING,
         allowed_mentions: AllowedMentions = MISSING,
         thread: Snowflake = MISSING,
+        thread_name: Optional[str] = None,
         wait: bool = False,
     ) -> Optional[SyncWebhookMessage]:
         """Sends a message using the webhook.
@@ -958,7 +966,7 @@ class SyncWebhook(BaseWebhook):
         ``embeds`` parameter, which must be a :class:`list` of :class:`Embed` objects to send.
 
         Parameters
-        ------------
+        ----------
         content: :class:`str`
             The content of the message to send.
         wait: :class:`bool`
@@ -992,10 +1000,14 @@ class SyncWebhook(BaseWebhook):
         thread: :class:`~discord.abc.Snowflake`
             The thread to send this message to.
 
+            .. versionadded:: 2.0
+        thread_name: :class:`str`
+            The name of the thread to create. Only works for forum channels.
+
             .. versionadded:: 2.0
 
         Raises
-        --------
+        ------
         HTTPException
             Sending the message failed.
         NotFound
@@ -1007,10 +1019,11 @@ class SyncWebhook(BaseWebhook):
         ValueError
             The length of ``embeds`` was invalid
         InvalidArgument
-            There was no token associated with this webhook.
+            There was no token associated with this webhook or you specified both
+            a thread to send to and a thread to create (the ``thread`` and ``thread_name`` parameters).
 
         Returns
-        ---------
+        -------
         Optional[:class:`SyncWebhookMessage`]
             If ``wait`` is ``True`` then the message that was sent, otherwise ``None``.
         """
@@ -1022,6 +1035,9 @@ class SyncWebhook(BaseWebhook):
         if content is None:
             content = MISSING
 
+        if thread and thread_name:
+            raise InvalidArgument("You cannot specify both a thread and a thread name")
+
         params = handle_message_parameters(
             content=content,
             username=username,
@@ -1047,6 +1063,7 @@ class SyncWebhook(BaseWebhook):
             multipart=params.multipart,
             files=params.files,
             thread_id=thread_id,
+            thread_name=thread_name,
             wait=wait,
         )
         if wait:
