@@ -1,17 +1,8 @@
 """
-    DISCORD ADVERTISEMENT FRAMEWORK (DAF)
-    Author      :: David Hozic
-    Copyright   :: Copyright (c) 2022 David Hozic
-    Version     :: V1.8
+Discord Advertisement Framework
+
+Version 2.0
 """
-
-
-"""
-TODO:
-- Documention for JSON logging
-"""
-
-
 import _discord as discord
 from .client import *
 from .const import *
@@ -20,3 +11,5 @@ from .dtypes import *
 from .guild import *
 from .message import *
 from .tracing import *
+from .sql import *
+from .exceptions import *
\ No newline at end of file
